@@ -212,6 +212,17 @@ sub task_run {
     my $tid      = shift or confess "usage: task_run(project,*task,parameters)";
     my @args     = @_; 
 
+    my $cli_args;
+
+    my $i=0;
+    for my $a (@args) {
+      if ($a eq '--') {
+        delete $args[$i];
+        $cli_args = join ' ', delete @args[$i .. $#args];
+        last;
+      }
+      $i++;
+    }
 
     my $verbose_mode     = 0; 
     my $noexec_mode      = 0;
@@ -339,6 +350,8 @@ sub task_run {
     $cmd.= " --story $story_arg" if $story_arg;
     $cmd.= " --args-file $args_file_arg" if $args_file_arg;
 
+    $cmd.= " -- $cli_args" if $cli_args;
+
     if ($cron_mode) {
         my $repo_file = sparrow_root.'/cache/report-'.$project.'-'.$tid.'-'.$$.'.txt';
         exec "( $cmd 1>$repo_file 2>\&1 && rm $repo_file  )  || ( cat $repo_file ; rm -v $repo_file; exit 1; )";
